{
  pkgs,
  inputs,
  config,
  ...
}:
let
  tex = pkgs.texlive.combine {
    inherit (pkgs.texlive) scheme-full;
  };
  my-python-packages =
    ps: with ps; [
      cryptography
      flask
      ipwhois
      numpy
      pandas
      pyasn
      pyshark
      requests
      scapy
      z3-solver
    ];
in
{
  home.packages = with pkgs; [
    (python3.withPackages my-python-packages)
    btop
    calibre
    celluloid # video player
    comma
    discord
    element-desktop
    foliate # epub reader
    fusee-launcher
    gcc
    gimp
    jellyfin-media-player
    neofetch
    nixpkgs-review
    qmk
    signal-desktop
    solo2-cli
    spotify
    unzip
    yt-dlp

    obsidian
    (lib.hiPrio (
      pkgs.writeShellScriptBin "obsidian" ''
        unset WAYLAND_DISPLAY
        ${pkgs.obsidian}/bin/obsidian
      ''
    ))
  ];
  # Enable my own hm modules
  themes.v.catppuccin.enable = true;
  programs = {
    v = {
      vscode.enable = true;
      nvim.enable = true;
      rust.enable = true;
    };

    zed-editor = {
      enable = true;
    };

    firefox.enable = true;

    chromium = {
      enable = true;
      extensions = [
        { id = "cjpalhdlnbpafiamejdnhcphjbkeiagm"; } # ublock origin
        { id = "nngceckbapebfimnlniiiahkandclblb"; } # bitwarden
      ];
    };

    direnv = {
      enable = true;
      nix-direnv.enable = true;
    };

    zsh = {
      enable = true;
      sessionVariables = {
        DIRENV_LOG_FORMAT = "";
      };
    };

    kitty = {
      enable = true;
      shellIntegration.enableZshIntegration = true;
    };
  };

  xdg.autoStart = {
    packages = with pkgs; [
      element-desktop
      firefox
      discord
      obsidian
    ];
  };

  # Syncthing
  services.syncthing.enable = true;
  xdg.userDirs =
    let
      home = config.home.homeDirectory;
    in
    {
      enable = true;
      createDirectories = true;
      desktop = "${home}/.desktop";
      documents = "${home}/cloud/Documents";
      download = "${home}/dl";
      music = "${home}/cloud/Music";
      pictures = "${home}/cloud/Pictures";
      publicShare = "${home}/.publicShare";
      templates = "${home}/.templates";
      videos = "${home}/cloud/Videos";
    };
}
